summaryrefslogtreecommitdiffstats
path: root/win/CS/HandBrakeWPF/Properties
diff options
context:
space:
mode:
authorsr55 <[email protected]>2019-01-14 22:17:45 +0000
committersr55 <[email protected]>2019-01-14 22:18:05 +0000
commit740348fefc3872d74b1a49752e48e36c20656303 (patch)
treecd26954a9c7eae2d5cf76d9291feba4056e7d81e /win/CS/HandBrakeWPF/Properties
parent8f99ad6571508d67b237ef106dc60c6cbec88f6d (diff)
WinGui: Initial support for SSA file import.
Diffstat (limited to 'win/CS/HandBrakeWPF/Properties')
-rw-r--r--win/CS/HandBrakeWPF/Properties/Resources.Designer.cs6
-rw-r--r--win/CS/HandBrakeWPF/Properties/Resources.de.resx4
-rw-r--r--win/CS/HandBrakeWPF/Properties/Resources.resx4
3 files changed, 7 insertions, 7 deletions
diff --git a/win/CS/HandBrakeWPF/Properties/Resources.de.resx b/win/CS/HandBrakeWPF/Properties/Resources.de.resx
index ae572bb56..de7a22085 100644
--- a/win/CS/HandBrakeWPF/Properties/Resources.de.resx
+++ b/win/CS/HandBrakeWPF/Properties/Resources.de.resx
@@ -1641,8 +1641,8 @@ Dies beeinflusst nicht die momentanen Einstellungen im Untertitel-Tab. </value>
<data name="SubtitlesView_BurnInBehaviour" xml:space="preserve">
<value>Einbrennverhalten:</value>
</data>
- <data name="SubtitlesView_ImportSRT" xml:space="preserve">
- <value>SRT importieren</value>
+ <data name="SubtitlesView_ImportSubtitle" xml:space="preserve">
+ <value>SRT / SSA importieren</value>
</data>
<data name="SubtitlesView_TrackSelectionBehaviour" xml:space="preserve">
<value>Spurverhalten:</value>
diff --git a/win/CS/HandBrakeWPF/Properties/Resources.resx b/win/CS/HandBrakeWPF/Properties/Resources.resx
index f611f0020..baf8533d9 100644
--- a/win/CS/HandBrakeWPF/Properties/Resources.resx
+++ b/win/CS/HandBrakeWPF/Properties/Resources.resx
@@ -1642,8 +1642,8 @@ This will not affect your current settings in the Subtitle tab.</value>
<data name="SubtitlesView_BurnInBehaviour" xml:space="preserve">
<value>Burn-In Behaviour:</value>
</data>
- <data name="SubtitlesView_ImportSRT" xml:space="preserve">
- <value>Import SRT</value>
+ <data name="SubtitlesView_ImportSubtitle" xml:space="preserve">
+ <value>Import Subtitle</value>
</data>
<data name="SubtitlesView_TrackSelectionBehaviour" xml:space="preserve">
<value>Track Selection Behaviour:</value>
diff --git a/win/CS/HandBrakeWPF/Properties/Resources.Designer.cs b/win/CS/HandBrakeWPF/Properties/Resources.Designer.cs
index f63893372..df97f4a66 100644
--- a/win/CS/HandBrakeWPF/Properties/Resources.Designer.cs
+++ b/win/CS/HandBrakeWPF/Properties/Resources.Designer.cs
@@ -4660,11 +4660,11 @@ namespace HandBrakeWPF.Properties {
}
/// <summary>
/// Looks up a localized string similar to Import SRT.
/// </summary>
- public static string SubtitlesView_ImportSRT {
+ public static string SubtitlesView_ImportSubtitle {
get {
- return ResourceManager.GetString("SubtitlesView_ImportSRT", resourceCulture);
+ return ResourceManager.GetString("SubtitlesView_ImportSubtitle", resourceCulture);
}
}
@@ -4660,11 +4660,11 @@ namespace HandBrakeWPF.Properties {
}
/// <summary>
- /// Looks up a localized string similar to Import SRT.
+ /// Looks up a localized string similar to Import Subtitle.
/// </summary>